@@ -1193,16 +1193,32 @@ static GnomeVFSResult
 copy_symlink (GnomeVFSURI *source_uri,
 	      GnomeVFSURI *target_uri,
 	      const char *link_name,
-	      GnomeVFSProgressCallbackState *progress)
+	      GnomeVFSXferErrorMode *error_mode,
+	      GnomeVFSProgressCallbackState *progress,
+	      gboolean *skip)
 {
 	GnomeVFSResult result;
-	
-	result = gnome_vfs_create_symbolic_link (target_uri, link_name);
-	
-	if (result == GNOME_VFS_OK && call_progress_with_uris_often (progress, source_uri,
-		target_uri, GNOME_VFS_XFER_PHASE_OPENTARGET) == 0) {
-		result = GNOME_VFS_ERROR_INTERRUPTED;
+	gboolean retry;
+
+	*skip = FALSE;
+	do {
+		retry = FALSE;
+		
+		result = gnome_vfs_create_symbolic_link (target_uri, link_name);
+
+		if (result != GNOME_VFS_OK) {
+			retry = handle_error (&result, progress, error_mode, skip);
+		} else if (result == GNOME_VFS_OK &&
+			   call_progress_with_uris_often (progress, source_uri,
+							  target_uri, GNOME_VFS_XFER_PHASE_OPENTARGET) == 0) {
+			result = GNOME_VFS_ERROR_INTERRUPTED;
+		}
+	} while (retry);
+
+	if (*skip) {
+		return GNOME_VFS_OK;
 	}
+	
 	return result;
 }
 
@@ -1408,7 +1424,7 @@ copy_directory (GnomeVFSFileInfo *source_file_info,
 						gnome_vfs_file_info_unref (symlink_target_info);
 					} else {
 						result = copy_symlink (source_uri, dest_uri, info->symlink_name,
-								       progress);
+								       error_mode, progress, skip);
 					}
 				}
 				/* just ignore all the other special file system objects here */
@@ -1532,7 +1548,7 @@ copy_items (const GList *source_uri_list,
 								 progress, &skip);
                                 } else if (info->type == GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK) {
 					result = copy_symlink (source_uri, target_uri, info->symlink_name,
-							       progress);
+							       error_mode, progress, &skip);
                                 }
 				/* just ignore all the other special file system objects here */
 
